@@ -35,14 +35,14 @@ private Q_SLOTS:
         QTest::newRow("Munich S1") << 48.13 << 11.58 << s("S1") << Line::RapidTransit << QColor(0xff36caec) << s("M%C3%BCnchen%20S1.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Munich S3") << 48.13 << 11.58 << s("S3") << Line::RapidTransit << QColor(0xff862996) << s("M%C3%BCnchen%20S3.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Munich U3") << 48.13 << 11.58 << s("U3") << Line::Metro << QColor(0xffe66432) << s("M%C3%BCnchen%20U3.svg") << s("U-Bahnlogo%20M%C3%BCnchen.svg");
-        QTest::newRow("Nurnberg S2") << 49.44 << 11.08 << s("S2") << Line::RapidTransit << QColor(0xff65b949) << QString() << s("S-Bahn-Logo.svg");
+        QTest::newRow("Nurnberg S2") << 49.44 << 11.08 << s("S2") << Line::RapidTransit << QColor(0xff65b949) << u"N%C3%BCrnberg%20S2.svg"_s << u"S-Bahn-Logo.svg"_s;
         QTest::newRow("Nurnberg U2") << 49.44 << 11.08 << s("U2") << Line::Metro << QColor(0xffff0000) << s("N%C3%BCrnberg%20U2.svg") << s("U-Bahn.svg");
-        QTest::newRow("Nurnberg tram 5") << 49.44 << 11.08 << u"5"_s << Line::Tramway << QColor(0xff8b539d) << u"N%C3%BCrnberg%20T5.png"_s << u"Tram%20N%C3%BCrnberg%20Logo.png"_s;
+        QTest::newRow("Nurnberg tram 5") << 49.44 << 11.08 << u"5"_s << Line::Tramway << QColor(0xff8b539d) << u"N%C3%BCrnberg%20T5.svg"_s << u"Tram%20N%C3%BCrnberg%20Logo.png"_s;
         QTest::newRow("Frankfurt U8") << 50.1 << 8.66 << s("U8") << Line::Metro << QColor(0xffc77db5) << s("Frankfurt%20U8.svg") << s("U-Bahn.svg");
         QTest::newRow("Brussels 2") << 50.83 << 4.33 << s("2") << Line::Metro << QColor(0xffed6c23) << s("STIB-MIVB%20Line%202.svg") << s("Brussels%20Metro%20Logo.svg");
         QTest::newRow("Brussels 82") << 50.83 << 4.33 << s("82") << Line::Tramway << QColor(0xff91bee7) << s("STIB-MIVB%20Line%2082.svg") << s("Brussels%20tramway%20icon.svg");
         QTest::newRow("Brussels S6") << 50.83 << 4.33 << s("S6") << Line::RapidTransit << QColor(0xff965f26) << QString() << s("NMBS%20S-Trein%20logo.svg");
-        QTest::newRow("Brussels S10") << 50.83 << 4.33 << s("S10") << Line::RapidTransit << QColor(0xff000000) << QString() << s("NMBS%20S-Trein%20logo.svg");
+        QTest::newRow("Brussels S10") << 50.83 << 4.33 << s("S10") << Line::RapidTransit << QColor(0xff000000) << u"S10-Tilo.svg"_s << u"NMBS%20S-Trein%20logo.svg"_s;
         QTest::newRow("Paris RER C") << 48.84 << 2.37 << s("C") << Line::RapidTransit << QColor(0xfffcd946) << s("Paris%20transit%20icons%20-%20RER%20C.svg") << s("Paris%20transit%20icons%20-%20RER.svg");
         QTest::newRow("Paris RER D") << 48.84 << 2.37 << u"D"_s << Line::RapidTransit << QColor(0xff00824e) << u"Paris%20transit%20icons%20-%20RER%20D.svg"_s << u"Paris%20transit%20icons%20-%20RER.svg"_s;
         QTest::newRow("Paris Metro 1") << 48.84 << 2.37 << u"1"_s << Line::Metro << QColor(0xffffbe00) << u"Paris%20transit%20icons%20-%20M%C3%A9tro%201.svg"_s << u"Paris%20transit%20icons%20-%20M%C3%A9tro.svg"_s;
@@ -57,7 +57,7 @@ private Q_SLOTS:
         QTest::newRow("Hamburg U1") << 53.55 << 10.0 << s("U1") << Line::Metro << QColor(0xff0066b3) << s("Hamburg%20U1.svg") << s("U-Bahn.svg");
         QTest::newRow("Hamburg S1") << 53.55 << 10.0 << s("S1") << Line::RapidTransit << QColor(0xff33b540) << s("Hamburg%20S1.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Copenhagen A") << 55.67 << 12.56 << s("A") << Line::RapidTransit << QColor(0xff00bfff) << s("S-train%20service%20A.svg") << s("S-tog.svg");
-        QTest::newRow("Cologne S11") << 50.94 << 6.97 << s("S11") << Line::RapidTransit << QColor(0xffef7c00) << s("NRW%20S11.svg") << s("S-Bahn-Logo.svg");
+        QTest::newRow("Cologne S11") << 50.94 << 6.97 << s("S11") << Line::RapidTransit << QColor(0xfff39200) << u"NRW%20S11.svg"_s << u"S-Bahn-Logo.svg"_s;
         QTest::newRow("Stuttgart S1") << 48.78 << 9.18 << s("S1") << Line::RapidTransit << QColor(0xff5c8e3c) << s("S1%20S-Bahn%20Stuttgart%20Logo%20(2021).svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Stuttgart U6") << 48.78 << 9.18 << s("U6") << Line::RapidTransit << QColor(0xffec008c) << u"Stuttgart%20U6.svg"_s << u"Logo%20Stadtbahn%20Stuttgart.svg"_s;
         QTest::newRow("Barcelona L1") << 41.37 << 2.13 << s("L1") << Line::Metro << QColor(0xffe33638) << s("L1%20barcelona.svg") << s("Barcelona%20Metro%20Logo.svg");
@@ -71,10 +71,11 @@ private Q_SLOTS:
         QTest::newRow("Rome Metro A") << 41.8989 << 12.5089 << s("A") << Line::Metro << QColor(0xfff68b1f) << s("Metropolitana%20di%20Roma%20-%20logo%20linea%20A.svg") << s("Logo%20Metropolitane%20Italia.svg");
         QTest::newRow("Gotenburg tram 6") << 57.7 << 11.96 << s("6") << Line::Tramway << QColor(0xfffa8719) << s("Sp%C3%A5rvagnslinje%206.svg") << QString();
         QTest::newRow("Amsterdam line 54") << 52.37 << 4.9 << u"54"_s << Line::Metro << QColor(0xfffcfb05) << u"Amsterdam%20transit%20icons%20-%20Metro%2054.svg"_s << u"Amsterdam%20metro%20logo.svg"_s;
-        QTest::newRow("Thessaloniki metro 2") << 40.64 << 22.93 << s("2") << Line::Metro << QColor(0xff0070ff) << s("Thessaloniki%20Metro%20Line%202.svg") << QString();
+        QTest::newRow("Thessaloniki metro 2") << 40.64 << 22.93 << s("2") << Line::Metro << QColor(0xff0070ff) << u"Thessaloniki%20Metro%20Line%202.svg"_s << u"Thessaloniki%20Metro%20logo.svg"_s;
         QTest::newRow("Graz S5") <<  47.1 << 15.4 << s("S5") << Line::RapidTransit << QColor(0xff8d1d81) << s("S5%20Steiermark.svg") << s("S-Bahn%20Austria.svg");
-        QTest::newRow("Zurich IC 1") << 47.37 << 8.54 << s("IC 1") << Line::LongDistanceTrain << QColor(0xffe43d2e) << s("IC%201%20logo.svg") << QString();
+        QTest::newRow("Zurich IC 1") << 47.37 << 8.54 << s("IC 1") << Line::LongDistanceTrain << QColor(0xffdd3327) << s("IC%201%20logo.svg") << QString();
         QTest::newRow("Wuerzburg Tram 1") << 49.80 << 9.93 << u"1"_s << Line::Tramway << QColor(0xffffbb00) << QString() << QString();
+        QTest::newRow("Budapest Tram 17") << 47.49 << 19.03 << u"17"_s << Line::Tramway << QColor(0xffffd800) << u"Budapest%20Tram%20line17%20icon.svg"_s << u"Logo%20tramway-budapest.svg"_s;
     }
 
     void testLookup()
