@@ -6,13 +6,13 @@
 
 #include "abstractbackend.h"
 #include "logging.h"
-#include "kpublictransport_version.h"
+#include "http/useragent_p.h"
+#include "standardpaths_p.h"
 
 #include <KPublicTransport/JourneyReply>
 #include <KPublicTransport/JourneyRequest>
 #include <KPublicTransport/Location>
 
-#include <QCoreApplication>
 #include <QDebug>
 #include <QDir>
 #include <QJsonDocument>
@@ -72,6 +72,33 @@ QString AbstractBackend::preferredLanguage() const
     return QStringLiteral("en");
 }
 
+QStringList AbstractBackend::preferredLanguages() const
+{
+    QStringList langs;
+    const auto localeLangs = QLocale().uiLanguages();
+    for (const auto &l : localeLangs) {
+        if (m_supportedLanguages.contains(l)) {
+            if (!langs.contains(l)) {
+                langs.push_back(l);
+            }
+            continue;
+        }
+        if (l.size() <= 2 || l[2] != '-'_L1) {
+            continue;
+        }
+        if (const auto l2 = QStringView(l).left(2); m_supportedLanguages.contains(l2) && !langs.contains(l2)) {
+            langs.push_back(l2.toString());
+        }
+    }
+
+    // ensure this is never empty
+    if (langs.empty() && !localeLangs.empty()) {
+        langs.push_back(localeLangs.front().left(2));
+    }
+
+    return langs;
+}
+
 void AbstractBackend::init()
 {
 }
@@ -234,7 +261,7 @@ bool AbstractBackend::queryVehicleLayout(const VehicleLayoutRequest &request, Ve
 
 void AbstractBackend::setCustomCaCertificate(const QString &caCert)
 {
-    QFile f(QLatin1String(":/org.kde.kpublictransport/network-certificates/") + caCert);
+    QFile f(StandardPaths::locateFile("networks/certs/"_L1 + caCert));
     if (!f.open(QFile::ReadOnly)) {
         qCWarning(Log) << f.fileName() << f.errorString();
         return;
@@ -244,7 +271,7 @@ void AbstractBackend::setCustomCaCertificate(const QString &caCert)
 
 void AbstractBackend::setPkcs12(const QString &pkcs12Name)
 {
-    QFile f(QLatin1String(":/org.kde.kpublictransport/network-certificates/") + pkcs12Name);
+    QFile f(StandardPaths::locateFile("networks/certs/"_L1 + pkcs12Name));
     if (!f.open(QFile::ReadOnly)) {
         qCWarning(Log) << f.fileName() << f.errorString();
         return;
@@ -273,11 +300,5 @@ void AbstractBackend::applySslConfiguration(QNetworkRequest &request) const
 
 void AbstractBackend::applyUserAgent(QNetworkRequest &request)
 {
-    if (!QCoreApplication::applicationVersion().isEmpty()) {
-        request.setHeader(QNetworkRequest::UserAgentHeader, ("org.kde.kpublictransport/"_L1 + QCoreApplication::applicationName()
-            + QLatin1Char('/') + QCoreApplication::applicationVersion()).toUtf8());
-    } else {
-        request.setHeader(QNetworkRequest::UserAgentHeader, ("org.kde.kpublictransport/"_L1 + QCoreApplication::applicationName()
-            + QLatin1Char('/') + QLatin1StringView(KPUBLICTRANSPORT_VERSION_STRING)).toUtf8());
-    }
+    request.setHeader(QNetworkRequest::UserAgentHeader, Http::userAgent().toUtf8());
 }
