@@ -200,8 +200,19 @@ void OpenTripPlannerParser::parseAlerts(const QJsonArray& alertsArray) const
     m_alerts.reserve(alertsArray.size());
     for (const auto &alertValue : alertsArray) {
         const auto alertObj = alertValue.toObject();
-        const auto descsArray = alertObj.value(QLatin1String("alertDescriptionTextTranslations")).toArray();
+        const auto descsArray = alertObj.value("alertDescriptionTextTranslations"_L1).toArray();
         if (descsArray.empty()) {
+            // new OTP2 alerts API
+            const auto hdr = alertObj.value("alertHeaderText"_L1).toString();
+            const auto desc = alertObj.value("alertDescriptionText"_L1).toString();
+            if (hdr.isEmpty() && desc.isEmpty()) {
+            } else if (hdr == desc || desc.isEmpty()) {
+                m_alerts.push_back(hdr);
+            } else if (hdr.isEmpty() || desc.startsWith(hdr)) {
+                m_alerts.push_back(desc);
+            } else {
+                m_alerts.push_back("<b>"_L1 + hdr + "</b><br/>"_L1 + desc);
+            }
             continue;
         }
 
@@ -209,7 +220,7 @@ void OpenTripPlannerParser::parseAlerts(const QJsonArray& alertsArray) const
         const auto uiLangs = QLocale().uiLanguages();
         int minIdx = 0, minWeight = std::numeric_limits<int>::max();
         for (int i = 0; i < descsArray.size(); ++i) {
-            const auto lang = descsArray.at(i).toObject().value(QLatin1String("language")).toString();
+            const auto lang = descsArray.at(i).toObject().value("language"_L1).toString();
             for (int j = 0; j < uiLangs.size() && j < minWeight; ++j) {
                 if (uiLangs.at(j).startsWith(lang)) {
                     minIdx = i;
@@ -219,7 +230,7 @@ void OpenTripPlannerParser::parseAlerts(const QJsonArray& alertsArray) const
             }
         }
 
-        m_alerts.push_back(descsArray.at(minIdx).toObject().value(QLatin1String("text")).toString());
+        m_alerts.push_back(descsArray.at(minIdx).toObject().value("text"_L1).toString());
     }
 }
 
@@ -231,26 +242,16 @@ static QColor parseColor(const QJsonValue &value)
     return QColor(QLatin1Char('#') + value.toString());
 }
 
-struct {
-    const char *name;
-    Feature::Availability availability;
-} static constexpr const bikes_allowed_map[] = {
-    { "ALLOWED", Feature::Available },
-    { "NOT_ALLOWED", Feature::Unavailable },
-    { "NO_INFORMATION", Feature::Unknown },
-    { "allowed", Feature::Available },
-    { "noInformation", Feature::Unknown },
-    { "notAllowed", Feature::Unavailable },
-};
-
 OpenTripPlannerParser::RouteData OpenTripPlannerParser::parseLine(const QJsonObject &obj) const
 {
     parseAlerts(obj.value(QLatin1String("alerts")).toArray());
 
     Line line;
-    line.setName(obj.value(QLatin1String("shortName")).toString());
-    if (line.name().isEmpty()) {
-        line.setName(obj.value(QLatin1String("longName")).toString());
+    for (const auto &key : {"shortName"_L1, "longName"_L1, "name"_L1}) {
+        line.setName(obj.value(key).toString());
+        if (!line.name().isEmpty()) {
+            break;
+        }
     }
     line.setOperatorName(obj.value("agency"_L1).toObject().value("name"_L1).toString());
 
@@ -274,26 +275,100 @@ OpenTripPlannerParser::RouteData OpenTripPlannerParser::parseLine(const QJsonObj
     RouteData data;
     data.route.setLine(line);
 
-    const auto bikesAllowed = obj.value("bikesAllowed"_L1).toString();
-    const auto it = std::find_if(std::begin(bikes_allowed_map), std::end(bikes_allowed_map), [&bikesAllowed](auto m) {
-        return bikesAllowed == QLatin1StringView(m.name);
-    });
-    if (it != std::end(bikes_allowed_map)) {
-        data.features.emplace_back(Feature::BikeStorage, (*it).availability);
-    }
     return data;
 }
 
+struct {
+    const char *name;
+    const char *enturName;
+    Load::Category occupancy;
+} constexpr inline const occupancy_map[] = {
+    { "CRUSHED_STANDING_ROOM_ONLY", "crushedStandingRoomOnly", Load::High },
+    { "EMPTY", "empty", Load::Low },
+    { "FEW_SEATS_AVAILABLE", "fewSeatsAvailable", Load::Medium },
+    { "FULL", "full", Load::Full },
+    { "MANY_SEATS_AVAILABLE", "manySeatsAvailable", Load::Low },
+    { "NOT_ACCEPTING_PASSENGERS", "notAcceptingPassengers", Load::Full },
+    { "NO_DATA_AVAILABLE", "noData", Load::Unknown },
+    { "STANDING_ROOM_ONLY", "standingRoomOnly", Load::High },
+};
+
+[[nodiscard]] static Load::Category parseOccupancy(const QJsonValue &v)
+{
+    QString occupancy;
+    if (v.isString()) {
+        occupancy = v.toString();
+    } else {
+        occupancy = v.toObject().value("occupancyStatus"_L1).toString();
+    }
+
+     for (const auto &m : occupancy_map) {
+        if (QLatin1StringView(m.name) == occupancy || QLatin1StringView(m.enturName) == occupancy) {
+            return m.occupancy;
+        }
+    }
+
+    if (!occupancy.isEmpty()) {
+        qDebug() << "Unknown OTP2 occupancy level:" << occupancy;
+    }
+    return Load::Unknown;
+}
+
+struct {
+    const char *name;
+    Feature::Availability availability;
+} static constexpr const bikes_allowed_map[] = {
+    { "ALLOWED", Feature::Available },
+    { "NOT_ALLOWED", Feature::Unavailable },
+    { "NO_INFORMATION", Feature::Unknown },
+    { "allowed", Feature::Available },
+    { "noInformation", Feature::Unknown },
+    { "notAllowed", Feature::Unavailable },
+};
+
+struct {
+    const char *name;
+    Feature::Availability availability;
+} static constexpr const wheelchair_access_map[] = {
+    { "NOT_POSSIBLE", Feature::Unavailable },
+    { "NO_INFORMATION", Feature::Unknown },
+    { "POSSIBLE", Feature::Available },
+    { "noInformation", Feature::Unknown },
+    { "notPossible", Feature::Unavailable },
+    { "possible", Feature::Available },
+};
+
 OpenTripPlannerParser::RouteData OpenTripPlannerParser::parseRoute(const QJsonObject &obj) const
 {
-    auto data = parseLine(obj.value(QLatin1String("route")).toObject());
+    auto data = parseLine(obj.value("route"_L1).toObject());
     auto line = data.route.line();
-    if (line.name().isEmpty()) {
-        line.setName(obj.value(QLatin1String("tripShortName")).toString());
+    if (const auto name = obj.value("tripShortName"_L1).toString(); !name.isEmpty()) {
+        line.setName(name);
     }
 
     data.route.setLine(line);
-    data.route.setDirection(obj.value(QLatin1String("tripHeadsign")).toString());
+    data.route.setDirection(obj.value("tripHeadsign"_L1).toString());
+    data.occupancy = parseOccupancy(obj.value("occupancy"_L1));
+
+    {
+        const auto bikesAllowed = obj.value("bikesAllowed"_L1).toString();
+        const auto it = std::find_if(std::begin(bikes_allowed_map), std::end(bikes_allowed_map), [&bikesAllowed](auto m) {
+            return bikesAllowed == QLatin1StringView(m.name);
+        });
+        if (it != std::end(bikes_allowed_map)) {
+            data.features.emplace_back(Feature::BikeStorage, (*it).availability);
+        }
+    }
+
+    {
+        const auto wheelchairAccess = obj.value("wheelchairAccessible"_L1).toString();
+        const auto it = std::find_if(std::begin(wheelchair_access_map), std::end(wheelchair_access_map), [&wheelchairAccess](auto m) {
+            return wheelchairAccess == QLatin1StringView(m.name);
+        });
+        if (it != std::end(wheelchair_access_map)) {
+            data.features.emplace_back(Feature::WheelchairAccessible, (*it).availability);
+        }
+    }
 
     return data;
 }
@@ -328,11 +403,66 @@ OpenTripPlannerParser::RouteData OpenTripPlannerParser::detectAndParseRoute(cons
     return parseInlineRoute(obj);
 }
 
-static QDateTime parseDepartureDateTime(uint64_t baseTime, const QJsonValue &value)
+struct {
+    const char *name;
+    PickupDropoff::Type type;
+} constexpr inline const pickupDropoff_map[] = {
+    { "CALL_AGENCY", PickupDropoff::CallAgency },
+    { "COORDINATE_WITH_DRIVER", PickupDropoff::CoordinateWithDriver },
+    { "NONE", PickupDropoff::NotAllowed },
+    { "SCHEDULED", PickupDropoff::Normal },
+};
+
+[[nodiscard]] PickupDropoff::Type parsePickupDropoffType(QStringView name)
+{
+    for (const auto &m :pickupDropoff_map) {
+        if (QLatin1StringView(m.name) == name) {
+            return m.type;
+        }
+    }
+    if (!name.isEmpty()) {
+        qDebug() << "Unknown pickup/dropoff value:" << name;
+    }
+    return PickupDropoff::Normal;
+}
+
+Stopover OpenTripPlannerParser::parseStoptime(const QJsonObject &obj) const
+{
+    Stopover s;
+    s.setStopPoint(parseLocation(obj));
+    s.setScheduledPlatform(obj.value("stop"_L1).toObject().value("platformCode"_L1).toString());
+
+    if (const auto occupancy = parseOccupancy(obj.value("occupancyStatus"_L1)); occupancy != Load::Category::Unknown) {
+        s.setLoadInformation({occupancy});
+    }
+    auto routeData = detectAndParseRoute(obj);
+    s.setRoute(routeData.route);
+    s.setFeatures(std::move(routeData.features));
+    if (routeData.occupancy != Load::Unknown) {
+        s.setLoadInformation({routeData.occupancy});
+    }
+
+    // OTP
+    s.setPickupType(parsePickupDropoffType(obj.value("pickupType"_L1).toString()));
+    s.setDropoffType(parsePickupDropoffType(obj.value("dropoffType"_L1).toString()));
+
+    // Entur
+    const auto requestStop = obj.value("requestStop"_L1).toBool(false);
+    if (const auto v = obj.value("forBoarding"_L1); v.isBool()) {
+        s.setPickupType(v.toBool() ? (requestStop ? PickupDropoff::CoordinateWithDriver : PickupDropoff::Normal) : PickupDropoff::NotAllowed);
+    }
+    if (const auto v = obj.value("forAlighting"_L1); v.isBool()) {
+        s.setDropoffType(v.toBool() ? (requestStop ? PickupDropoff::CoordinateWithDriver : PickupDropoff::Normal) : PickupDropoff::NotAllowed);
+    }
+
+    return s;
+}
+
+static QDateTime parseDepartureDateTime(qint64 baseTime, const QJsonValue &value)
 {
     if (value.isDouble()) { // encoded as seconds offset to baseTime
         // UNIX timestamp of midnight in local timezone + UNIX timestamp of local time
-        auto dt = QDateTime::fromSecsSinceEpoch(baseTime + value.toDouble());
+        auto dt = QDateTime::fromSecsSinceEpoch(baseTime + value.toInteger());
         dt = dt.toTimeZone(QTimeZone::UTC);
         return dt;
     }
@@ -341,18 +471,15 @@ static QDateTime parseDepartureDateTime(uint64_t baseTime, const QJsonValue &val
 
 Stopover OpenTripPlannerParser::parseDeparture(const QJsonObject &obj) const
 {
-    Stopover dep;
-    const auto baseTime = obj.value(QLatin1String("serviceDay")).toDouble(); // ### 64bit
-    dep.setScheduledArrivalTime(parseDepartureDateTime(baseTime, obj.value(QLatin1String("scheduledArrival"))));
-    dep.setScheduledDepartureTime(parseDepartureDateTime(baseTime, obj.value(QLatin1String("scheduledDeparture"))));
-    if (obj.value(QLatin1String("realtime")).toBool()) {
-        dep.setExpectedArrivalTime(parseDepartureDateTime(baseTime, obj.value(QLatin1String("realtimeArrival"))));
-        dep.setExpectedDepartureTime(parseDepartureDateTime(baseTime, obj.value(QLatin1String("realtimeDeparture"))));
+    auto dep = parseStoptime(obj);
+    dep.setTripIdentifier(m_identifierType, obj.value("trip"_L1).toObject().value("id"_L1).toString());
+    const auto baseTime = obj.value("serviceDay"_L1).toInteger();
+    dep.setScheduledArrivalTime(parseDepartureDateTime(baseTime, obj.value("scheduledArrival"_L1)));
+    dep.setScheduledDepartureTime(parseDepartureDateTime(baseTime, obj.value("scheduledDeparture"_L1)));
+    if (obj.value("realtime"_L1).toBool()) {
+        dep.setExpectedArrivalTime(parseDepartureDateTime(baseTime, obj.value("realtimeArrival"_L1)));
+        dep.setExpectedDepartureTime(parseDepartureDateTime(baseTime, obj.value("realtimeDeparture"_L1)));
     }
-    dep.setScheduledPlatform(obj.value(QLatin1String("stop")).toObject().value(QLatin1String("platformCode")).toString());
-    auto routeData = detectAndParseRoute(obj);
-    dep.setRoute(routeData.route);
-    dep.setFeatures(std::move(routeData.features));
     dep.addNotes(m_alerts);
     m_alerts.clear();
 
@@ -400,7 +527,7 @@ static QDateTime parseJourneyDateTime(const QJsonValue &val)
 {
     if (val.isDouble()) {
         // timestamp, as UTC value
-        auto dt = QDateTime::fromMSecsSinceEpoch(val.toDouble()); // ### sic! double to get 64 bit precision...
+        auto dt = QDateTime::fromMSecsSinceEpoch(val.toInteger());
         dt = dt.toTimeZone(QTimeZone::UTC);
         return dt;
     }
@@ -420,40 +547,59 @@ static RentalVehicle::VehicleType vehicleTypeFromTypes(RentalVehicle::VehicleTyp
 
 JourneySection OpenTripPlannerParser::parseJourneySection(const QJsonObject &obj) const
 {
-    JourneySection section;
-    section.setScheduledDepartureTime(parseJourneyDateTime(obj.value(QLatin1String("startTime"))));
-    section.setScheduledArrivalTime(parseJourneyDateTime(obj.value(QLatin1String("endTime"))));
-    if (obj.value(QLatin1String("realTime")).toBool()) {
-        section.setExpectedDepartureTime(parseJourneyDateTime(obj.value(QLatin1String("expectedStartTime"))));
-        if (!section.expectedDepartureTime().isValid()) {
-            section.setExpectedDepartureTime(section.scheduledDepartureTime().addSecs(obj.value(QLatin1String("departureDelay")).toInt()));
+    auto dep = parseStoptime(obj.value("fromStoptime"_L1).toObject()); // Entur only
+    auto arr = parseStoptime(obj.value("toStoptime"_L1).toObject());
+
+    dep.setScheduledDepartureTime(parseJourneyDateTime(obj.value("startTime"_L1)));
+    arr.setScheduledArrivalTime(parseJourneyDateTime(obj.value("endTime"_L1)));
+    if (obj.value("realTime"_L1).toBool()) {
+        dep.setExpectedDepartureTime(parseJourneyDateTime(obj.value("expectedStartTime"_L1)));
+        if (!dep.expectedDepartureTime().isValid()) {
+            dep.setExpectedDepartureTime(dep.scheduledDepartureTime().addSecs(obj.value("departureDelay"_L1).toInteger()));
         }
-        section.setExpectedArrivalTime(parseJourneyDateTime(obj.value(QLatin1String("expectedEndTime"))));
-        if (!section.expectedArrivalTime().isValid()) {
-            section.setExpectedArrivalTime(section.scheduledArrivalTime().addSecs(obj.value(QLatin1String("arrivalDelay")).toInt()));
+        arr.setExpectedArrivalTime(parseJourneyDateTime(obj.value("expectedEndTime"_L1)));
+        if (!arr.expectedArrivalTime().isValid()) {
+            arr.setExpectedArrivalTime(arr.scheduledArrivalTime().addSecs(obj.value("arrivalDelay"_L1).toInteger()));
         }
     }
 
-    const auto fromObj = obj.value(QLatin1String("from")).toObject();
-    const auto fromStop = fromObj.value(QLatin1String("stop")).toObject();
+    const auto fromObj = obj.value("from"_L1).toObject();
+    const auto fromStop = fromObj.value("stop"_L1).toObject();
     const auto from = parseLocation(fromObj);
-    section.setFrom(from);
-    section.setScheduledDeparturePlatform(fromStop.value(QLatin1String("platformCode")).toString());
+    dep.setStopPoint(from);
+    dep.setScheduledPlatform(fromStop.value("platformCode"_L1).toString());
 
-    const auto toObj = obj.value(QLatin1String("to")).toObject();
-    const auto toStop = toObj.value(QLatin1String("stop")).toObject();
+    const auto toObj = obj.value("to"_L1).toObject();
+    const auto toStop = toObj.value("stop"_L1).toObject();
     const auto to = parseLocation(toObj);
-    section.setTo(to);
-    section.setScheduledArrivalPlatform(toStop.value(QLatin1String("platformCode")).toString());
+    arr.setStopPoint(to);
+    arr.setScheduledPlatform(toStop.value("platformCode"_L1).toString());
 
-    section.setDistance(obj.value(QLatin1String("distance")).toDouble());
+    // OTP only
+    if (const auto pickup = obj.value("pickupType"_L1).toString(); !pickup.isEmpty()) {
+        dep.setPickupType(parsePickupDropoffType(pickup));
+    }
+    if (const auto dropoff = obj.value("dropoffType"_L1).toString(); !dropoff.isEmpty()) {
+        arr.setDropoffType(parsePickupDropoffType(dropoff));
+    }
 
-    if (obj.value(QLatin1String("transitLeg")).toBool()) {
+    JourneySection section;
+    section.setDeparture(dep);
+    section.setArrival(arr);
+    section.setDistance(obj.value("distance"_L1).toDouble());
+
+    if (obj.value("transitLeg"_L1).toBool()) {
         section.setMode(JourneySection::PublicTransport);
         section.setIdentifier(m_identifierType, obj.value("trip"_L1).toObject().value("id"_L1).toString());
+        if (const auto occupancy = parseOccupancy(obj.value("occupancy"_L1)); occupancy != Load::Category::Unknown) {
+            section.setLoadInformation({occupancy});
+        }
         auto routeData = detectAndParseRoute(obj);
         section.setRoute(routeData.route);
         section.setFeatures(std::move(routeData.features));
+        if (routeData.occupancy != Load::Unknown) {
+            section.setLoadInformation({routeData.occupancy});
+        }
     } else {
         const auto mode = obj.value(QLatin1String("mode")).toString();
         const auto isRented = obj.value(QLatin1String("rentedBike")).toBool();
@@ -493,11 +639,8 @@ JourneySection OpenTripPlannerParser::parseJourneySection(const QJsonObject &obj
     stops.reserve(stopsA.size());
     for (const auto &stopV : stopsA) {
         const auto stopObj = stopV.toObject();
-        const auto loc = parseLocation(stopObj);
 
-        Stopover stop;
-        stop.setStopPoint(loc);
-        stop.setScheduledPlatform(stopObj.value(QLatin1String("platformCode")).toString());
+        auto stop = parseStoptime(stopObj);
         stop.setScheduledArrivalTime(parseJourneyDateTime(stopObj.value(QLatin1String("scheduledArrivalTime"))));
         stop.setScheduledDepartureTime(parseJourneyDateTime(stopObj.value(QLatin1String("scheduledDepartureTime"))));
         stop.setExpectedArrivalTime(parseJourneyDateTime(stopObj.value(QLatin1String("expectedArrivalTime"))));
@@ -614,9 +757,7 @@ JourneySection OpenTripPlannerParser::parseTrip(const QJsonObject &obj) const
     stops.reserve(stoptimesA.size());
     for (const auto &stoptimeV :stoptimesA) {
         const auto stopObj = stoptimeV.toObject();
-
-        Stopover stop;
-        stop.setStopPoint(parseLocation(stopObj));
+        auto stop = parseStoptime(stopObj);
         const auto serviceDay = stopObj.value("serviceDay"_L1).toInteger();
         stop.setScheduledDepartureTime(QDateTime::fromSecsSinceEpoch(serviceDay + stopObj.value("scheduledDeparture"_L1).toInteger()));
         stop.setScheduledArrivalTime(QDateTime::fromSecsSinceEpoch(serviceDay + stopObj.value("scheduledArrival"_L1).toInteger()));
