@@ -22,7 +22,7 @@
 
 using namespace KPublicTransport;
 
-QString Json::translatedValue(const QJsonObject &obj, const QString &key)
+QString Json::translatedValue(const QJsonObject &obj, QLatin1StringView key)
 {
     auto languageWithCountry = QLocale().name();
     auto it = obj.constFind(key + QLatin1Char('[') + languageWithCountry + QLatin1Char(']'));
@@ -251,7 +251,7 @@ void Json::fromJson(const QMetaObject *mo, const QJsonObject &obj, void *elem)
         }
 
         const auto prop = mo->property(idx);
-        if (!prop.isStored() || !prop.isWritable()) {
+        if (!prop.isWritable()) { // we accept !isStored() here, for deserializing legacy data
             continue;
         }
 
@@ -291,6 +291,8 @@ void Json::fromJson(const QMetaObject *mo, const QJsonObject &obj, void *elem)
         }
 
         const auto v = variantFromJson(it.value(), prop.userType());
-        prop.writeOnGadget(elem, v);
+        if (!v.isNull()) {
+            prop.writeOnGadget(elem, v);
+        }
     }
 }
