@@ -86,14 +86,26 @@ QString Location::region() const
 void Location::setCountry(const QString &countryCode)
 {
     d.detach();
+    if (countryCode.size() != 2 || std::ranges::any_of(countryCode, [](QChar c) { return c.row() != 0 || !c.isLetter() || !c.isUpper(); })) {
+        const auto c = KCountry::fromName(countryCode);
+        if (c.isValid()) {
+            d->country = c.alpha2();
+            return;
+        }
+    }
     d->country = countryCode;
 }
 
 QString Location::country() const
 {
     if (d->country.isEmpty() && hasCoordinate()) {
-        auto country = KCountry::fromLocation((float)latitude(), (float)longitude());
+        const auto country = KCountry::fromLocation((float)latitude(), (float)longitude());
         const_cast<Location *>(this)->setCountry(country.alpha2());
+    } else if (d->country.size() != 2 && hasCoordinate()) {
+        const auto country = KCountry::fromLocation((float)latitude(), (float)longitude());
+        if (country.isValid()) {
+            const_cast<Location *>(this)->setCountry(country.alpha2());
+        }
     }
 
     return d->country;
